==> percona-server-mongodb_4.0.9.orig.tar.gz: percona-server-mongodb-4.0.9-4/src/mongo/gotools/src/github.com/mongodb/mongo-tools/mongodump/prepare_test.go <==
// Copyright (C) MongoDB, Inc. 2014-present.
//
// Licensed under the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License. You may obtain
// a copy of the License at http://www.apache.org/licenses/LICENSE-2.0

package mongodump

import (
	"testing"

	"github.com/mongodb/mongo-tools/common/testtype"
	. "github.com/smartystreets/goconvey/convey"
)

func TestSkipCollection(t *testing.T) {

	testtype.VerifyTestType(t, testtype.UnitTestType)

	Convey("With a mongodump that excludes collections 'test' and 'fake'"+
		" and excludes prefixes 'pre-' and 'no'", t, func() {
		md := &MongoDump{
			OutputOptions: &OutputOptions{
				ExcludedCollections:        []string{"test", "fake"},
				ExcludedCollectionPrefixes: []string{"pre-", "no"},
			},
		}

		Convey("collection 'pre-test' should be skipped", func() {
			So(md.shouldSkipCollection("pre-test"), ShouldBeTrue)
		})

		Convey("collection 'notest' should be skipped", func() {
			So(md.shouldSkipCollection("notest"), ShouldBeTrue)
		})

		Convey("collection 'test' should be skipped", func() {
			So(md.shouldSkipCollection("test"), ShouldBeTrue)
		})

		Convey("collection 'fake' should be skipped", func() {
			So(md.shouldSkipCollection("fake"), ShouldBeTrue)
		})

		Convey("collection 'fake222' should not be skipped", func() {
			So(md.shouldSkipCollection("fake222"), ShouldBeFalse)
		})

		Convey("collection 'random' should not be skipped", func() {
			So(md.shouldSkipCollection("random"), ShouldBeFalse)
		})

		Convey("collection 'mytest' should not be skipped", func() {
			So(md.shouldSkipCollection("mytest"), ShouldBeFalse)
		})
	})

}

type testTable struct {
	db     string
	coll   string
	output bool
}

func TestShouldSkipSystemNamespace(t *testing.T) {
	tests := []testTable{
		testTable{
			db:     "test",
			coll:   "system",
			output: false,
		},
		testTable{
			db:     "test",
			coll:   "system.nonsense",
			output: true,
		},
		testTable{
			db:     "test",
			coll:   "system.js",
			output: false,
		},
		testTable{
			db:     "test",
			coll:   "test",
			output: false,
		},
	}

	for _, testVals := range tests {
		if shouldSkipSystemNamespace(testVals.db, testVals.coll) != testVals.output {
			t.Errorf("%s.%s should have been %v but failed\n", testVals.db, testVals.coll, testVals.output)
		}
	}
}

==> percona-server-mongodb-34_3.4.23.orig.tar.gz: percona-server-mongodb-3.4.23-2.21/src/mongo/gotools/src/github.com/mongodb/mongo-tools/mongodump/prepare_test.go <==
package mongodump

import (
	"testing"

	"github.com/mongodb/mongo-tools/common/testtype"
	. "github.com/smartystreets/goconvey/convey"

	"gopkg.in/mgo.v2/bson"
)

func TestSkipCollection(t *testing.T) {

	testtype.VerifyTestType(t, testtype.UnitTestType)

	Convey("With a mongodump that excludes collections 'test' and 'fake'"+
		" and excludes prefixes 'pre-' and 'no'", t, func() {
		md := &MongoDump{
			OutputOptions: &OutputOptions{
				ExcludedCollections:        []string{"test", "fake"},
				ExcludedCollectionPrefixes: []string{"pre-", "no"},
			},
		}

		Convey("collection 'pre-test' should be skipped", func() {
			So(md.shouldSkipCollection("pre-test"), ShouldBeTrue)
		})

		Convey("collection 'notest' should be skipped", func() {
			So(md.shouldSkipCollection("notest"), ShouldBeTrue)
		})

		Convey("collection 'test' should be skipped", func() {
			So(md.shouldSkipCollection("test"), ShouldBeTrue)
		})

		Convey("collection 'fake' should be skipped", func() {
			So(md.shouldSkipCollection("fake"), ShouldBeTrue)
		})

		Convey("collection 'fake222' should not be skipped", func() {
			So(md.shouldSkipCollection("fake222"), ShouldBeFalse)
		})

		Convey("collection 'random' should not be skipped", func() {
			So(md.shouldSkipCollection("random"), ShouldBeFalse)
		})

		Convey("collection 'mytest' should not be skipped", func() {
			So(md.shouldSkipCollection("mytest"), ShouldBeFalse)
		})
	})

}

var (
	testSystemDB = "sysjstestdb"
)

func setUpTestSystemJS() error {
	session, err := getBareSession()
	if err != nil {
		return err
	}
	defer session.Close()

	collectionName := "system.js"

	coll := session.DB(testSystemDB).C(collectionName)

	err = coll.Insert(bson.M{"_id": "echoFunction", "value": "function(x) { return x; }"})
	if err != nil {
		return err
	}

	return nil
}

func TestCreateIntentsForDatabase(t *testing.T) {
	testtype.VerifyTestType(t, testtype.IntegrationTestType)

	Convey("With a MongoDump instance create an intent for system.js", t, func() {
		err := setUpTestSystemJS()
		So(err, ShouldBeNil)

		md := simpleMongoDumpInstance()
		md.InputOptions.Query = ""

		md.ToolOptions.Namespace.Collection = "system.js"
		err = md.Init()
		So(err, ShouldBeNil)

		err = md.CreateIntentsForDatabase(testSystemDB)
		So(err, ShouldBeNil)
		So(len(md.manager.Intents()), ShouldEqual, 1)

	})
}
